[−][src]Struct bbqueue_ng::framed::FrameProducer
A producer of Framed data
Implementations
impl<'a, const N: usize> FrameProducer<'a, { N }>[src]
pub fn grant(&mut self, max_sz: usize) -> Result<FrameGrantW<'a, { N }>>[src]
Receive a grant for a frame with a maximum size of max_sz in bytes.
This size does not include the size of the frame header. The exact size
of the frame can be set on commit.